# Jetplot

![build](https://github.com/nirum/jetplot/workflows/build/badge.svg)
[![codecov](https://codecov.io/gh/nirum/jetplot/branch/master/graph/badge.svg)](https://codecov.io/gh/nirum/jetplot)

## About

`jetplot` is collection of miscellaneous utils for Matplotlib.


## Installation

```bash
pip install jetplot
```

## Documentation

Coming soon.


## Changelog

| Version | Release Date | Description                                                                                                                                                                                                     |
| ------: | :----------: | :-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| 0.4.0   | Oct 20 2021  | Name change! Renamed package from `jetpack` to `jetplot`.                                                                                                                                                       |
| 0.3.0   | Oct 13 2021  | Drops animation module and the `moviepy` dependency                                                                                                                                                             |
| 0.0.0   | Jan 19 2015  | Initial commit                                                                                                                                                                                                  |

## License

MIT. See [`LICENSE.md`](./LICENSE.md)
